-- Code for Cypress 37064 mounted on PC104 to IC converter

-- Libraries

library IEEE;                           -- IEEE library
use IEEE.std_logic_1164.all;            -- basic logic types
USE work.STD_ARITH.all;




  ------------------------------ Variables ------------------------------------

entity IO is port
(
	ISA_AEN:	in std_logic;						-- Adress Enable
	ISA_IOW: 	in std_logic;						-- ISA write order

	ISA_Ad:		in std_logic_vector(9 downto 0);	-- ISA Adress
	Board_Ad:	in std_logic_vector(9 downto 3);	-- Board adress selction (Switch)

	PCA_Reset:	out std_logic;						-- PCA9564's reset
	PCA_CS:		out std_logic						-- PCA9564's chip select
);

  ------------------------ Attribute pin number -------------------------------

attribute pin_numbers of IO: entity is 
	"ISA_AEN:40 ISA_IOW:38"
	&" ISA_Ad(9):41 ISA_Ad(8):42 ISA_Ad(7):43 ISA_Ad(6):2 ISA_Ad(5):3 ISA_Ad(4):4 ISA_Ad(3):5 ISA_Ad(2):6 ISA_Ad(1):9 ISA_Ad(0):8"
	&" Board_Ad(9):36 Board_Ad(8):35 Board_Ad(7):33 Board_Ad(6):32 Board_Ad(5):31 Board_Ad(4):30 Board_Ad(3):29"
	&" PCA_Reset:28 PCA_CS:37";
end IO;

 
  ----------------------------- Architecture ------------------------------------

architecture arch_IO of IO is 
begin

  ----------------------------- CS ------------------------------------

	PCA_CS<='0' when 	(ISA_Ad(9)=Board_Ad(9)) 
					AND	(ISA_Ad(8)=Board_Ad(8)) 
					AND	(ISA_Ad(7)=Board_Ad(7)) 
					AND	(ISA_Ad(6)=Board_Ad(6)) 
					AND	(ISA_Ad(5)=Board_Ad(5)) 
					AND	(ISA_Ad(4)=Board_Ad(4)) 
					AND	(ISA_Ad(3)=Board_Ad(3)) 
					AND	(ISA_Ad(2)='0') 
					AND (ISA_AEN='0') 
					else '1';

  ----------------------------- Reset ------------------------------------

	process (ISA_IOW)
	begin
		if (ISA_IOW'event and ISA_IOW='1') then
			
			if (ISA_Ad(9)=Board_Ad(9)) 
				AND	(ISA_Ad(8)=Board_Ad(8)) 
				AND	(ISA_Ad(7)=Board_Ad(7)) 
				AND	(ISA_Ad(6)=Board_Ad(6)) 
				AND	(ISA_Ad(5)=Board_Ad(5)) 
				AND	(ISA_Ad(4)=Board_Ad(4)) 
				AND	(ISA_Ad(3)=Board_Ad(3)) 
				AND	(ISA_Ad(2)='1') 
				AND	(ISA_Ad(1)='0') 
				AND	(ISA_Ad(0)='0') 
				AND (ISA_AEN='0')  then PCA_Reset<='0';
			end if;

			if (ISA_Ad(9)=Board_Ad(9)) 
				AND	(ISA_Ad(8)=Board_Ad(8)) 
				AND	(ISA_Ad(7)=Board_Ad(7)) 
				AND	(ISA_Ad(6)=Board_Ad(6)) 
				AND	(ISA_Ad(5)=Board_Ad(5)) 
				AND	(ISA_Ad(4)=Board_Ad(4)) 
				AND	(ISA_Ad(3)=Board_Ad(3)) 
				AND	(ISA_Ad(2)='1') 
				AND	(ISA_Ad(1)='0') 
				AND	(ISA_Ad(0)='1') 
				AND (ISA_AEN='0')  then PCA_Reset<='1';
			end if;
		end if;
	end process;

end architecture arch_IO;
